@@ -11,22 +11,20 @@ use Class::XSAccessor
     monitoringdata_endpoint => "monitoringdata_endpoint",
     verbose                 => "verbose",
     ssl_verify_hostname     => "ssl_verify_hostname",
-    use_time_piece          => "use_time_piece",
   },
   #true    => [qw(verbose)],
   replace => 1;
 
-#has apikey => ( is => "rw", isa => "Str" );
+#has api_key => ( is => "rw", isa => "Str" );
 #has timeout => ( is => "rw", isa => "Num" );
 #has verbose => ( is => "rw", isa => "Num" );
 #has ssl_verify_hostname => ( is => "rw", isa => "Num");
 use Module::Pluggable search_path => [__PACKAGE__];
 
-our $VERSION                 = '0.13_05';
+our $VERSION                 = '0.1';
 our $AGENT                   = sprintf "%s/%s", __PACKAGE__, $VERSION;
 our $SSL_VERIFY_HOSTNAME     = 1;
 our $TIMEOUT                 = 30;
-our $USE_TIME_PIECE          = 1;
 our $DEFAULT_ENDPOINT        = "https://papi.giraffi.jp";
 our $MONITORINGDATA_ENDPOINT = "https://okapi.giraffi.jp:3007";
 our $APPLOGS_ENDPOINT        = "https://lapi.giraffi.jp:3443";
@@ -39,15 +37,14 @@ sub import {
         $pkg =~ /^${class}::([a-zA-Z]+)$/;
         my $method = lc $1;
 
-        no strict "refs";        ## no critic
-		no warnings "redefine";  ## no critic
+        no strict "refs";    ## no critic
         *{ __PACKAGE__ . "::$method" } = sub {
             my $self    = shift;
             my %options = (
                 apikey                   => $self->apikey,
                 agent                    => $AGENT,
-                ssl_verify_hostname      => $self->ssl_verify_hostname // $SSL_VERIFY_HOSTNAME,
-                use_time_piece           => $self->use_time_piece // $USE_TIME_PIECE,
+                ssl_verify_hostname      => $self->ssl_verify_hostname
+                // $SSL_VERIFY_HOSTNAME,
                 timeout                  => $self->timeout // $TIMEOUT,
                 default_endpoint         => $self->default_endpoint // $DEFAULT_ENDPOINT,
                 monitoringdata_endpoint  => $self->monitoringdata_endpoint // $MONITORINGDATA_ENDPOINT,
@@ -84,7 +81,7 @@ WWW::Giraffi::API - Giraffi API Access Module
 
 =head1 VERSION
 
-0.13_05
+0.1
 
 =head1 SYNOPSIS
 
@@ -92,8 +89,8 @@ WWW::Giraffi::API - Giraffi API Access Module
   use warnings;
   use WWW::Giraffi::API;
   
-  my $apikey = "ilovenirvana_ilovekurtcobain";
-  my $g = WWW::Giraffi::API->new(apikey => $apikey);
+  my $api_key = "ilovenirvana_ilovekurtcobain";
+  my $g = WWW::Giraffi::API->new(api_key => $api_key);
   # get all media data
   my $arrayref = $g->media->find;
   foreach $ref(@{$arrayref}) {
@@ -120,10 +117,6 @@ for LWP::UserAgent ssl_opts(verify_hostname => $this_value). 1
 
 for LWP::UserAgent timeout. 30
 
-=head2 $USE_TIME_PIECE
-
-convert unix timestamp fields in json response to Time::Piece Object. default 1
-
 =head2 $DEFAULT_ENDPOINT
 
 https://papi.giraffi.jp
@@ -142,18 +135,10 @@ https://lapi.giraffi.jp:3443"
 
 =head2 timeout
 
-=head2 default_endpoint
-
-=head2 applogs_endpoint
-
-=head2 monitoringdata_endpoint
-
 =head2 verbose
 
 =head2 ssl_verify_hostname
 
-=head2 use_time_piece
-
 =head1 METHOD
 
 =head2 new
@@ -162,19 +147,18 @@ Create WWW::Giraffi::API Object
 
 Example:
 
-  my $apikey = "ilovenirvana_ilovekurtcobain";
-  my $g = WWW::Giraffi::API->new(apikey => $apikey);
+  my $api_key = "ilovenirvana_ilovekurtcobain";
+  my $g = WWW::Giraffi::API->new(api_key => $api_key);
 
 Options
 
-  apikey                    giraffi apikey
+  api_key                   giraffi api_key
   timeout                   connection timeout. default 30sec 
   default_endpoint          default_endpoint. default $DEFAULT_ENDPOINT
-  applogs_endpoint          applogs_endpoint. default $APPLOGS_ENDPOINT
-  monitoringdata_endpoint   monitoringdata_endpoint. default $MONITORINGDATA_ENDPOINT
+  applogs_endpoint          applogs_endpoint. default $MONITORINGDATA_ENDPOINT
+  monitoringdata_endpoint   monitoringdata_endpoint. default $APPLOGS_ENDPOINT
   verbose                   verbose output. default 0
   ssl_verify_hostname       ssl_verify_hostname(for LWP::UserAgent). default 1
-  use_time_piece            use_time_piece. default $USE_TIME_PIECE
 
 =head2 media
 
@@ -182,7 +166,7 @@ Create WWW::Giraffi::API::Media Object
 
 Example:
 
-  my $g = WWW::Giraffi::API->new(apikey => $apikey);
+  my $g = WWW::Giraffi::API->new(api_key => $api_key);
   my $media = $g->media;
 
 =head2 axion
