@@ -6,19 +6,19 @@ use Time::Piece;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.13_05';
+our $VERSION = '0.1';
 
 sub all {
 
-    my ( $self, $other_options ) = @_;
-	return $self->search(undef, $other_option);
+    my ( $self, $convert_time_piece ) = @_;
+	return $self->search(undef, $convert_time_piece);
 }
 
 sub search {
 	# no test
-    my ( $self, $conditions, $other_options ) = @_;
-    my $arrayref = $self->get( "applogs.json", $conditions, $other_options );
-    if ($self->use_time_piece) {
+    my ( $self, $conditions, $convert_time_piece ) = @_;
+    my $arrayref = $self->get( "applogs.json", $conditions );
+    if ($convert_time_piece) {
         my $tmp_arrayref = [];
         foreach my $ref(@{$arrayref}) {
             $ref->{applog}->{time} = localtime($ref->{applog}->{time});
@@ -31,8 +31,8 @@ sub search {
 
 sub create {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    return $self->post( sprintf("%s/applogs.json", $self->applogs_endpoint), undef, { applog => $conditions }, $other_options );
+    my ( $self, $conditions ) = @_;
+    return $self->post( sprintf("%s/applogs.json", $self->applogs_endpoint), undef, { applog => $conditions } );
 }
 
 1;
@@ -45,7 +45,7 @@ WWW::Giraffi::API::AppLog - Giraffi API AppLog Method Module
 
 =head1 VERSION
 
-0.13_05
+0.1
 
 =head1 SYNOPSIS
 
@@ -90,12 +90,12 @@ Return Array Reference:
      }
   ]
 
-unix timestamp will be changed into Time::Piece Object.
+unix timestamp will be changed into Time::Piece Object if 1 is passed to the 1st argument. 
 
 Example:
 
-  $applog->use_time_piece(1);
-  my $arrayref = $applog->all;
+  my $convert_time_piece = 1;
+  my $arrayref = $applog->all($convert_time_piece);
   # time is Time::Piece Object
   [
     {
@@ -144,12 +144,12 @@ Return Array Reference:
      }
   ]
 
-unix timestamp will be changed into Time::Piece Object.
+unix timestamp will be changed into Time::Piece Object if 1 is passed to the 2nd argument. 
 
 Example:
 
-  $applog->use_time_piece(1);
-  my $arrayref = $applog->search($conditions);
+  my $convert_time_piece = 1;
+  my $arrayref = $applog->search($conditions,$convert_time_piece);
 
 =head2 create
 
