@@ -6,19 +6,19 @@ use Time::Piece;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.13_05';
+our $VERSION = '0.1';
 
 sub all {
 
-    my ( $self, $other_options ) = @_;
-    return $self->search(undef, $other_options);
+    my ( $self, $convert_time_piece ) = @_;
+    return $self->search( undef, $convert_time_piece );
 }
 
 sub search {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    my $arrayref = $self->get( "logs/axion.json", $conditions, $other_options );
-	if ($self->use_time_piece) {
+    my ( $self, $conditions, $convert_time_piece ) = @_;
+    my $arrayref = $self->get( "logs/axion.json", $conditions );
+	if ($convert_time_piece) {
 		my $tmp_arrayref = [];
 		foreach my $ref(@{$arrayref}) {
 			$ref->{executed_at} = localtime($ref->{executed_at});
@@ -33,8 +33,8 @@ sub search {
 
 sub count {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    return $self->get( "logs/axion/count.json", $conditions, $other_options );
+    my ( $self, $conditions ) = @_;
+    return $self->get( "logs/axion/count.json", $conditions );
 }
 
 1;
@@ -47,7 +47,7 @@ WWW::Giraffi::API::Log - Giraffi API Axion Log Method Module
 
 =head1 VERSION
 
-0.13_05
+0.1
 
 =head1 SYNOPSIS
 
@@ -116,12 +116,12 @@ Return Array Reference:
           }
   ]
 
-unix timestamp will be changed into Time::Piece Object.
+unix timestamp will be changed into Time::Piece Object if 1 is passed to the 1st argument. 
 
 Example:
 
-  $log->use_time_piece(1);
-  my $arrayref = $log->all;
+  my $convert_time_piece = 1;
+  my $arrayref = $log->all($convert_time_piece);
   # created_at/checked_at/executed_at is Time::Piece Object
   [
           {
@@ -227,13 +227,13 @@ Return Array Reference:
           }
   ]
 
-unix timestamp will be changed into Time::Piece Object.
+unix timestamp will be changed into Time::Piece Object if 1 is passed to the 2nd argument.
 convert field is same as all method result 
 
 Example:
 
-  $log->use_time_piece(1);
-  my $arrayref = $log->search($conditions);
+  my $convert_time_piece = 1;
+  my $arrayref = $log->search($conditions, $convert_time_piece);
 
 =head2 count
 
