@@ -5,54 +5,54 @@ use warnings;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.13_05';
+our $VERSION = '0.1';
 
 sub all {
 
-    my ( $self, $other_options ) = @_;
-    return $self->search(undef, $other_options);
+    my ( $self ) = @_;
+    return $self->search;
 }
 
 sub search {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    return $self->get( "media.json", $conditions, $other_options );
+    my ( $self, $conditions ) = @_;
+    return $self->get( "media.json", $conditions );
 }
 
 sub find {
 
-    my ( $self, $id, $other_options ) = @_;
-    return $self->get( sprintf( "media/%s.json", $id ), undef, $other_options );
+    my ( $self, $id ) = @_;
+    return $self->get( sprintf( "media/%s.json", $id ) );
 }
 
 sub find_oauth {
 
-	my($self, $id, $other_options) = @_;
-    return $self->get( sprintf( "media/%s/oauth.json", $id ), undef, $other_options );
+	my($self, $id) = @_;
+    return $self->get( sprintf( "media/%s/oauth.json", $id ) );
 }
 
 sub find_oauth_callback {
 
-	my($self, $id, $oauth_verifier, $other_options) = @_;
-    return $self->get( sprintf( "media/%s/oauth_callback.json", $id ), { oauth_verifier => $oauth_verifier}, $other_options );
+	my($self, $id, $oauth_verifier) = @_;
+    return $self->get( sprintf( "media/%s/oauth_callback.json", $id ), { oauth_verifier => $oauth_verifier} );
 }
 
 sub create {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    return $self->post( "media.json", undef, { medium => $conditions }, $other_options );
+    my ( $self, $conditions ) = @_;
+    return $self->post( "media.json", undef, { medium => $conditions } );
 }
 
 sub update {
 
-    my ( $self, $id, $conditions, $other_options ) = @_;
-    return $self->put( sprintf("media/%s.json", $id), undef, { medium => $conditions }, $other_options );
+    my ( $self, $id, $conditions ) = @_;
+    return $self->put( sprintf("media/%s.json", $id), undef, { medium => $conditions } );
 }
 
 sub destroy {
 
-    my ( $self, $id, $other_options ) = @_;
-    return $self->delete( sprintf("media/%s.json", $id), undef, undef, $other_options );
+    my ( $self, $id ) = @_;
+    return $self->delete( sprintf("media/%s.json", $id) );
 }
 
 1;
@@ -65,7 +65,7 @@ WWW::Giraffi::API::Media - Giraffi API Media Method Access Module
 
 =head1 VERSION
 
-0.13_05
+0.1
 
 =head1 SYNOPSIS
 
