@@ -6,14 +6,14 @@ use Time::Piece;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.13_05';
+our $VERSION = '0.1';
 
 
 sub search {
 	# no test
-    my ( $self, $conditions, $other_options ) = @_;
-    my $arrayref = $self->get( "monitoringdata.json", $conditions, $other_options );
-	if ($self->use_time_piece) {
+    my ( $self, $conditions, $convert_time_piece ) = @_;
+    my $arrayref = $self->get( "monitoringdata.json", $conditions );
+	if ($convert_time_piece) {
 		my $tmp_arrayref = [];
 		foreach my $ref(@{$arrayref}) {
 			$ref->{checked_at} = localtime($ref->{checked_at});
@@ -27,8 +27,8 @@ sub search {
 
 sub create {
 	# no test
-    my ( $self, $conditions, $other_options ) = @_;
-    return $self->post( sprintf("%s/internal/nodelayed", $self->monitoringdata_endpoint), undef, { internal => $conditions }, $other_options );
+    my ( $self, $conditions ) = @_;
+    return $self->post( sprintf("%s/internal/nodelayed", $self->monitoringdata_endpoint), undef, { internal => $conditions } );
 }
 
 1;
@@ -41,7 +41,7 @@ WWW::Giraffi::API::MonitoringData - Giraffi API MonitoringData Method Module
 
 =head1 VERSION
 
-0.13_05
+0.1
 
 =head1 SYNOPSIS
 
@@ -94,12 +94,12 @@ Return Array Reference:
           }
   ]
 
-unix timestamp will be changed into Time::Piece Object.
+unix timestamp will be changed into Time::Piece Object if 1 is passed to the 2nd argument. 
 
 Example:
 
-  $monitoring->use_time_piece(1);
-  my $arrayref = $monitoring->search($conditions);
+  my $convert_time_piece = 1;
+  my $arrayref = $monitoring->search($conditions,$convert_time_piece);
   # created_at/checked_at is Time::Piece Object
   [
          {
