@@ -9,7 +9,6 @@ use Class::XSAccessor
     apikey                  => "apikey",
     agent                   => "agent",
     ssl_verify_hostname     => "ssl_verify_hostname",
-    use_time_piece          => "use_time_piece",
     timeout                 => "timeout",
     default_endpoint        => "default_endpoint",
     applogs_endpoint        => "applogs_endpoint",
@@ -26,7 +25,7 @@ use HTTP::Request;
 use HTTP::Response;
 use URI;
 
-our $VERSION         = '0.13_05';
+our $VERSION         = '0.1';
 our %REQUEST_HEADERS = (
     "Accept"       => "application/json",
     "Content-Type" => "application/json"
@@ -45,51 +44,45 @@ our $CLIENT_TIMEOUT_CODE  = 408;
 
 sub get {
 
-    my ( $self, $path_or_uri, $queryref, $other_options ) = @_;
-    my $res = $self->request( "GET", $path_or_uri, $queryref, undef, $other_options );
+    my ( $self, $path_or_uri, $queryref ) = @_;
+    my $res = $self->request( "GET", $path_or_uri, $queryref );
 	#return $self->_json2ref( $res->content );
     return $self->_response2ref( $res );
 }
 
 sub post {
 
-    my ( $self, $path_or_uri, $queryref, $contentref, $other_options ) = @_;
-    my $res = $self->request( "POST", $path_or_uri, $queryref, $contentref, $other_options );
+    my ( $self, $path_or_uri, $queryref, $contentref ) = @_;
+    my $res = $self->request( "POST", $path_or_uri, $queryref, $contentref );
 	#return $self->_json2ref( $res->content );
     return $self->_response2ref( $res );
 }
 
 sub put {
 
-    my ( $self, $path_or_uri, $queryref, $contentref, $other_options ) = @_;
-    my $res = $self->request( "PUT", $path_or_uri, $queryref, $contentref, $other_options );
+    my ( $self, $path_or_uri, $queryref, $contentref ) = @_;
+    my $res = $self->request( "PUT", $path_or_uri, $queryref, $contentref );
 	#return $self->_json2ref( $res->content );
     return $self->_response2ref( $res );
 }
 
 sub delete {
 
-    my ( $self, $path_or_uri, $queryref, $contentref, $other_options ) = @_;
-    my $res = $self->request( "DELETE", $path_or_uri, $queryref, $contentref, $other_options );
+    my ( $self, $path_or_uri, $queryref, $contentref ) = @_;
+    my $res = $self->request( "DELETE", $path_or_uri, $queryref, $contentref );
 	#return $self->_json2ref( $res->content );
     return $self->_response2ref( $res );
 }
 
 sub request {
 
-    my ( $self, $method, $path_or_uri, $queryref, $contentref, $other_options ) = @_;
-    my $req = $self->make_request( $method, $path_or_uri, $queryref, $contentref, $other_options );
-	return $self->_request($req);
-}
-
-sub _request {
-
-	my($self, $req) = @_;
+    my ( $self, $method, $path_or_uri, $queryref, $contentref ) = @_;
 
     my $ua = LWP::UserAgent->new( agent => $self->agent, timeout => $self->timeout );
     if ( !$self->ssl_verify_hostname ) {
         $ua->ssl_opts( verify_hostname => 0 );
     }
+    my $req = $self->make_request( $method, $path_or_uri, $queryref, $contentref );
     $self->_verbose( sprintf "request request_line %s => %s", $req->method, $req->uri );
 	if ($req->content) {
 	   $self->_verbose( sprintf "request content => %s", $req->content );
@@ -114,13 +107,10 @@ sub _request {
     return $res;
 }
 
-
-
-
 sub make_request {
 
-    my($self, $method, $path_or_uri, $queryref, $contentref, $other_options) = @_;
-    my $req = HTTP::Request->new( $method => $self->_make_uri( $path_or_uri, $queryref, $other_options ) );
+    my($self, $method, $path_or_uri, $queryref, $contentref) = @_;
+    my $req = HTTP::Request->new( $method => $self->_make_uri( $path_or_uri, $queryref ) );
     if ( $req->method =~ /^(POST|PUT|DELETE)$/ && ref($contentref) =~ /^(ARRAY|HASH)$/ ) {
         $req->header(%REQUEST_HEADERS);
         $req->content( $self->_ref2json($contentref) );
@@ -196,22 +186,15 @@ sub _verbose {
 
 sub _make_uri {
 
-    my ( $self, $path_or_uri, $queryref, $other_options ) = @_;
+    my ( $self, $path_or_uri, $queryref ) = @_;
 
     $queryref //= {};
     if ( $path_or_uri !~ /^https?:\/\// ) {
         $path_or_uri = sprintf "%s/%s", $self->default_endpoint, $path_or_uri;
     }
 
-	my $apikey;
-	if (ref($other_options) eq "HASH" && exists $other_options->{apikey}) {
-		$apikey = $other_options->{apikey};
-	} else {
-		$apikey = $self->apikey;
-	}
-
     my $uri = URI->new($path_or_uri);
-    $uri->query_form( [ apikey => $apikey, %{$queryref} ] );
+    $uri->query_form( [ apikey => $self->apikey, %{$queryref} ] );
     return $uri;
 }
 
@@ -224,7 +207,7 @@ WWW::Giraffi::API::Request - Giraffi API Access Request Base Module
 
 =head1 VERSION
 
-0.13_05
+0.1
 
 =head1 SYNOPSIS
 
@@ -273,8 +256,6 @@ request headers hash
 
 =head2 ssl_verify_hostname
 
-=head2 use_time_piece
-
 =head2 timeout
 
 =head2 default_endpoint
