@@ -5,66 +5,66 @@ use warnings;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.13_05';
+our $VERSION = '0.1';
 
 sub all {
 
-    my ( $self, $other_options ) = @_;
-    return $self->search(undef, $other_options);
+    my ( $self ) = @_;
+    return $self->search;
 }
 
 sub search {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    return $self->get( "services.json", $conditions, $other_options );
+    my ( $self, $conditions ) = @_;
+    return $self->get( "services.json", $conditions );
 }
 
 sub find {
 
-    my ( $self, $id, $other_options ) = @_;
-    return $self->get( sprintf( "services/%s.json", $id ), undef, $other_options );
+    my ( $self, $id ) = @_;
+    return $self->get( sprintf( "services/%s.json", $id ) );
 }
 
 sub find_region {
 
-    my ( $self, $id, $other_options ) = @_;
-    return $self->get( sprintf( "services/%s/regions.json", $id ), undef, $other_options );
+    my ( $self, $id ) = @_;
+    return $self->get( sprintf( "services/%s/regions.json", $id ) );
 }
 
 sub find_trigger {
 
-    my ( $self, $id, $other_options ) = @_;
-    return $self->get( sprintf( "services/%s/triggers.json", $id ), undef, $other_options );
+    my ( $self, $id ) = @_;
+    return $self->get( sprintf( "services/%s/triggers.json", $id ) );
 }
 
 sub update {
 
-    my ( $self, $id, $conditions, $other_options ) = @_;
-    return $self->put( sprintf("services/%s.json", $id), undef, { service => $conditions }, $other_options );
+    my ( $self, $id, $conditions ) = @_;
+    return $self->put( sprintf("services/%s.json", $id), undef, { service => $conditions } );
 }
 
 sub update_region {
 
-    my ( $self, $id, $region_code, $other_options ) = @_;
-    return $self->put( sprintf("services/%s/regions/%s.json", $id, $region_code), undef, {}, $other_options );
+    my ( $self, $id, $region_code ) = @_;
+    return $self->put( sprintf("services/%s/regions/%s.json", $id, $region_code), undef, {} );
 }
 
 sub destroy {
 
-    my ( $self, $id, $other_options ) = @_;
-    return $self->delete( sprintf("services/%s.json", $id), undef, undef, $other_options );
+    my ( $self, $id ) = @_;
+    return $self->delete( sprintf("services/%s.json", $id) );
 }
 
 sub add_trigger {
 
-    my ( $self, $id, $conditions, $other_options ) = @_;
-    return $self->post( sprintf("services/%s/triggers.json", $id), undef, { trigger => $conditions }, $other_options );
+    my ( $self, $id, $conditions ) = @_;
+    return $self->post( sprintf("services/%s/triggers.json", $id), undef, { trigger => $conditions } );
 }
 
 sub remove_trigger {
 
-    my ( $self, $id, $trigger_id, $other_options ) = @_;
-    return $self->delete( sprintf("services/%s/triggers/%s.json", $id, $trigger_id), undef, undef, $other_options );
+    my ( $self, $id, $trigger_id ) = @_;
+    return $self->delete( sprintf("services/%s/triggers/%s.json", $id, $trigger_id) );
 }
 1;
 
@@ -76,7 +76,7 @@ WWW::Giraffi::API::Service - Giraffi API Service Method Service Module
 
 =head1 VERSION
 
-0.13_05
+0.1
 
 =head1 SYNOPSIS
 
