@@ -6,13 +6,13 @@ use Time::Piece;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.13_05';
+our $VERSION = '0.1';
 
 sub search_average {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    my $arrayref = $self->get( "trends/average.json", $conditions, $other_options );
-	if ($self->use_time_piece) {
+    my ( $self, $conditions, $convert_time_piece ) = @_;
+    my $arrayref = $self->get( "trends/average.json", $conditions );
+	if ($convert_time_piece) {
 		my $tmp_arrayref = [];
 		foreach my $ref(@{$arrayref}) {
 			$ref->{checked_at} = localtime($ref->{checked_at});
@@ -25,9 +25,9 @@ sub search_average {
 
 sub search_failure {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    my $arrayref = $self->get( "trends/failure.json", $conditions, $other_options );
-	if ($self->use_time_piece) {
+    my ( $self, $conditions, $convert_time_piece ) = @_;
+    my $arrayref = $self->get( "trends/failure.json", $conditions );
+	if ($convert_time_piece) {
 		my $tmp_arrayref = [];
 		foreach my $ref(@{$arrayref}) {
 			$ref->{failed_start_at} = localtime($ref->{failed_start_at});
@@ -50,7 +50,7 @@ WWW::Giraffi::API::Trend - Giraffi API Axion Trend Method Module
 
 =head1 VERSION
 
-0.13_05
+0.1
 
 =head1 SYNOPSIS
 
@@ -123,12 +123,12 @@ Return Array Reference:
      }
   ]
 
-unix timestamp will be changed into Time::Piece Object
+unix timestamp will be changed into Time::Piece Object if 1 is passed to the 2nd argument. 
 
 Example:
 
-  $trend->use_time_piece(1);
-  my $arrayref = $trend->search_average($conditions);
+  my $convert_time_piece = 1;
+  my $arrayref = $trend->search_average($conditions, $convert_time_piece);
   # checked_at is Time::Piece Object
   [
      {
@@ -191,12 +191,12 @@ Return Array Reference:
     },
   ]
 
-unix timestamp(failed_start_at/failed_end_at key) will be changed into Time::Piece Object. 
+unix timestamp(failed_start_at/failed_end_at key) will be changed into Time::Piece Object if 1 is passed to the 2nd argument. 
 
 Example:
 
-  $trend->use_time_piece(1);
-  my $arrayref = $trend->search_failure($conditions);
+  my $convert_time_piece = 1;
+  my $arrayref = $trend->search_failure($conditions, 1);
 
 =head1 AUTHOR
 
